
# Slot: all_of


holds if all of the expressions hold

URI: [linkml:slot_expression_all_of](https://w3id.org/linkml/slot_expression_all_of)


## Domain and Range

[SlotExpression](SlotExpression.md) &#8594;  <sub>0..\*</sub> [AnonymousSlotExpression](AnonymousSlotExpression.md)

## Parents

 *  is_a: [all_of](all_of.md)

## Children


## Used by

 * [AnonymousSlotExpression](AnonymousSlotExpression.md)
 * [SlotDefinition](SlotDefinition.md)
 * [SlotExpression](SlotExpression.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Exact Mappings:** | | sh:and |

